from unittest import TestCase

from google_play_scraper.features.permissions import permissions


class TestPermission(TestCase):
    def test_reply_data_all_types(self):
        result = permissions("com.spotify.music", lang="en", country="us")

        self.assertDictEqual(
            {
                "Device ID & call information": ["read phone status and identity"],
                "Identity": ["add or remove accounts", "find accounts on the device"],
                "Storage": [
                    "modify or delete the contents of your USB storage",
                    "read the contents of your USB storage",
                ],
                "Phone": ["read phone status and identity"],
                "Microphone": ["record audio"],
                "Wi-Fi connection information": ["view Wi-Fi connections"],
                "Contacts": ["find accounts on the device"],
                "Camera": ["take pictures and videos"],
                "Photos/Media/Files": [
                    "modify or delete the contents of your USB storage",
                    "read the contents of your USB storage",
                ],
                "Other": [
                    "access Bluetooth settings",
                    "allow Wi-Fi Multicast reception",
                    "change network connectivity",
                    "change your audio settings",
                    "control Near Field Communication",
                    "control vibration",
                    "full network access",
                    "install shortcuts",
                    "pair with Bluetooth devices",
                    "prevent device from sleeping",
                    "run at startup",
                    "send sticky broadcast",
                    "use accounts on the device",
                    "view network connections",
                ],
                "Uncategorized": ["receive data from Internet"],
            },
            result,
        )

    def test_reply_data_only_other_type(self):
        result = permissions("example.matharithmetics", lang="en", country="us")

        self.assertDictEqual(
            {
                "Wi-Fi connection information": ["view Wi-Fi connections"],
                "Photos/Media/Files": [
                    "modify or delete the contents of your USB storage",
                    "read the contents of your USB storage",
                ],
                "Storage": [
                    "modify or delete the contents of your USB storage",
                    "read the contents of your USB storage",
                ],
                "Other": [
                    "control vibration",
                    "full network access",
                    "run at startup",
                    "view network connections",
                ],
            },
            result,
        )



from .constants.google_play import Sort
from .features.app import app
from .features.reviews import reviews, reviews_all
from .features.permissions import permissions

VERSION = __version__ = "1.0.3"



from unittest import TestCase
from unittest.mock import patch

from google_play_scraper.features.reviews import reviews_all, reviews


class TestReviewsAll(TestCase):
    def test_request_once(self):
        with patch(
            "google_play_scraper.features.reviews.reviews", wraps=reviews
        ) as mock_reviews:
            result = reviews_all("co.kr.uaram.userdeliver_")
            self.assertEqual(1, mock_reviews.call_count)

        result_of_reviews, _ = reviews("co.kr.uaram.userdeliver_", count=10000)

        self.assertTrue(0 < len(result) < 10)
        self.assertEqual(len(result), len(result_of_reviews))

    def test_request_multiple_times(self):
        with patch(
            "google_play_scraper.features.reviews.reviews", wraps=reviews
        ) as mock_reviews:
            result = reviews_all("co.kr.uaram.userdeliver_", lang="ko", country="kr")
            self.assertEqual(3, mock_reviews.call_count)

        result_of_reviews, _ = reviews(
            "co.kr.uaram.userdeliver_", lang="ko", country="kr", count=10000
        )

        self.assertTrue(300 < len(result) < 500)
        self.assertEqual(len(result), len(result_of_reviews))

    def test_no_reviews(self):
        result = reviews_all("product.dp.io.ab180blog", lang="sw", country="it")

        self.assertListEqual([], result)
